@@ -74,7 +74,6 @@ class Utilities(script_utilities.Utilities):
 
         return ""
 
-
     def selectedText(self, obj):
         string, start, end = super().selectedText(obj)
         if -1 not in [start, end]:
@@ -105,3 +104,26 @@ class Utilities(script_utilities.Utilities):
             return []
 
         return super().unrelatedLabels(root, onlyShowing, minimumWords)
+
+    def isLayoutOnly(self, obj):
+        if super().isLayoutOnly(obj):
+            return True
+
+        if obj.getRole() == pyatspi.ROLE_PANEL and obj.childCount == 1:
+            displayedLabel = self.displayedLabel(obj)
+            if displayedLabel == obj[0].name and obj[0].getRole() != pyatspi.ROLE_LABEL:
+                msg = "GNOME SHELL: %s is deemed to be layout only" % obj
+                debug.println(debug.LEVEL_INFO, msg, True)
+                return True
+
+        return False
+
+    def isBogusWindowFocusClaim(self, event):
+        if event.type.startswith('object:state-changed:focused') and event.detail1 \
+           and event.source.getRole() == pyatspi.ROLE_WINDOW \
+           and not self.canBeActiveWindow(event.source):
+            msg = "GNOME SHELL: Event is believed to be bogus window focus claim"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
+        return False
